==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QGraphicsSceneResizeEvent_shell.cpp <==
#include "QGraphicsSceneResizeEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneResizeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneResizeEvent")
    QGraphicsSceneResizeEvent *_ptr = reinterpret_cast<QGraphicsSceneResizeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneResizeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneResizeEvent_shell) ); }

jmethodID QGraphicsSceneResizeEvent_shell::__shell_javaMethod(int pos) const { return QGraphicsSceneResizeEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneResizeEvent), pos); }

// emitting (writeShellConstructor)
QGraphicsSceneResizeEvent_shell::QGraphicsSceneResizeEvent_shell()
    : QGraphicsSceneResizeEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent_shell()", QGraphicsSceneResizeEvent_shell::__shell())
    QGraphicsSceneResizeEvent_shell::__shell()->constructed(typeid(QGraphicsSceneResizeEvent));
}

// emitting (writeShellDestructor)
QGraphicsSceneResizeEvent_shell::~QGraphicsSceneResizeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneResizeEvent::~QGraphicsSceneResizeEvent()", QGraphicsSceneResizeEvent_shell::__shell())
    QGraphicsSceneResizeEvent_shell::__shell()->destructed(typeid(QGraphicsSceneResizeEvent));
}

void QGraphicsSceneResizeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneResizeEvent_shell*>(ptr)->QGraphicsSceneResizeEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneResizeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneResizeEvent()
void __qt_construct_QGraphicsSceneResizeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneResizeEvent()")
#if QT_CONFIG(graphicsview)
    Q_UNUSED(__java_arguments)
    QGraphicsSceneResizeEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneResizeEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneResizeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent()")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneResizeEvent, sizeof(QGraphicsSceneResizeEvent_shell), typeid(QGraphicsSceneResizeEvent), true, &deleter_QGraphicsSceneResizeEvent, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGraphicsSceneResizeEvent_shell
void __qt_destruct_QGraphicsSceneResizeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneResizeEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneResizeEvent_shell*>(ptr)->~QGraphicsSceneResizeEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneResizeEvent::newSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_newSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::newSize()const", __qt_this)
        QSizeF __qt_return_value = __qt_this->newSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneResizeEvent::oldSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_oldSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::oldSize()const", __qt_this)
        QSizeF __qt_return_value = __qt_this->oldSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneResizeEvent::setNewSize(QSizeF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_setNewSize_1native_1cref_1QSizeF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::setNewSize(QSizeF)", __qt_this)
        const QSizeF& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSizeF>(size0);
        __qt_this->setNewSize(__qt_size0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(size0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneResizeEvent::setOldSize(QSizeF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_setOldSize_1native_1cref_1QSizeF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::setOldSize(QSizeF)", __qt_this)
        const QSizeF& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSizeF>(size0);
        __qt_this->setOldSize(__qt_size0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(size0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGraphicsSceneResizeEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneResizeEvent>("QGraphicsSceneResizeEvent", "io/qt/widgets/QGraphicsSceneResizeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGraphicsSceneResizeEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneResizeEvent, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneResizeEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneResizeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QGraphicsSceneEvent, QGraphicsSceneResizeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QGraphicsSceneResizeEvent_shell.cpp <==
#include "QGraphicsSceneResizeEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneResizeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneResizeEvent")
    QGraphicsSceneResizeEvent *_ptr = reinterpret_cast<QGraphicsSceneResizeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneResizeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneResizeEvent_shell) ); }

jmethodID QGraphicsSceneResizeEvent_oshell::__shell_javaMethod(int pos) const { return QGraphicsSceneResizeEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneResizeEvent), pos); }

// emitting (writeShellDestructor)
QGraphicsSceneResizeEvent_shell::~QGraphicsSceneResizeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneResizeEvent::~QGraphicsSceneResizeEvent()", this)
    QGraphicsSceneResizeEvent_shell::__shell()->destructed(typeid(QGraphicsSceneResizeEvent));
}

// emitting (writeShellConstructor)
QGraphicsSceneResizeEvent_shell::QGraphicsSceneResizeEvent_shell()
    : QGraphicsSceneResizeEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent_shell()", this)
    QGraphicsSceneResizeEvent_shell::__shell()->constructed(typeid(QGraphicsSceneResizeEvent));
}

void QGraphicsSceneResizeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneResizeEvent_shell*>(ptr)->QGraphicsSceneResizeEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneResizeEvent));
}

void QGraphicsSceneResizeEvent_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneResizeEvent_oshell*>(ptr)->QGraphicsSceneResizeEvent_oshell::__shell()->tryDeleteShell(typeid(QGraphicsSceneResizeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QEvent* QGraphicsSceneResizeEvent_oshell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneResizeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QEvent*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipAndInvalidate(__jni_env, __java_return_value);
                } else {
                    QGraphicsSceneResizeEvent_shell::__shell()->warnForMethod("QGraphicsSceneResizeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QGraphicsSceneResizeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QEvent::clone();
        }
    }else{
        return QEvent::clone();
    }
}

void QGraphicsSceneResizeEvent_oshell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneResizeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QGraphicsSceneResizeEvent_shell::__shell()->warnForMethod("QGraphicsSceneResizeEvent::setAccepted(bool)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QGraphicsSceneResizeEvent::setAccepted(bool)");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneResizeEvent()
void __qt_construct_QGraphicsSceneResizeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneResizeEvent()")
#if QT_CONFIG(graphicsview)
    Q_UNUSED(__java_arguments)
    QGraphicsSceneResizeEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QGraphicsSceneResizeEvent_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QGraphicsSceneResizeEvent_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__qtjambi_has_overrides)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneResizeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneResizeEvent::QGraphicsSceneResizeEvent()")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneResizeEvent, sizeof(QGraphicsSceneResizeEvent_shell), typeid(QGraphicsSceneResizeEvent), 0, true, &deleter_QGraphicsSceneResizeEvent, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGraphicsSceneResizeEvent_shell
void __qt_destruct_QGraphicsSceneResizeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneResizeEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneResizeEvent_shell*>(ptr)->~QGraphicsSceneResizeEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneResizeEvent::newSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_newSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::newSize()const", __this_nativeId)
        QSizeF __qt_return_value = __qt_this->newSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneResizeEvent::oldSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_oldSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::oldSize()const", __this_nativeId)
        QSizeF __qt_return_value = __qt_this->oldSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneResizeEvent::setNewSize(QSizeF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_setNewSize_1native_1cref_1QSizeF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::setNewSize(QSizeF)", __this_nativeId)
        const QSizeF& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSizeF>(size0);
        __qt_this->setNewSize(__qt_size0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(size0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneResizeEvent::setOldSize(QSizeF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneResizeEvent_setOldSize_1native_1cref_1QSizeF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneResizeEvent::setOldSize(QSizeF)", __this_nativeId)
        const QSizeF& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSizeF>(size0);
        __qt_this->setOldSize(__qt_size0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(size0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGraphicsSceneResizeEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneResizeEvent>("QGraphicsSceneResizeEvent", "io/qt/widgets/QGraphicsSceneResizeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QGraphicsSceneResizeEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneResizeEvent, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneResizeEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneResizeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QGraphicsSceneEvent, QGraphicsSceneResizeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}
